Common tools for all packages
==========================================


For users
-----------

* scoring.py provides the **dreamtools-scoring** utility. Type ::

    dreamtools-scoring --help

For developers
-----------------

* layout.py provides an utility to create challenge layout automatically (**dreamtools-layout**)

::

    dreamtools-layout --help

* tools.py provides tools related to R language
* challenge.py provides the ABC class for all challenges
* downloader.py	is used to get data from synapse
* rocs.py	some basic tools for ROC analysis
* sageutils.py	Simple class around synapse client
* settings.py create a configuration file for dreamtools (may not be used)
* ziptools.py tools to read ZIP files
